@@ -19,15 +19,14 @@ class ImageOverlay(skrt.image.Image):
 
     def __init__(self, path="", load=True, image=None, *args, **kwargs):
 
+        kwargs['default_intensity'] = kwargs.get('default_intensity', None)
         skrt.image.Image.__init__(self, path, load, *args, **kwargs)
         self.set_image(image)
 
         # Default dose plotting settings
         self._default_cmap = "jet"
         self._default_colorbar_label = "Intensity"
-        self._default_vmin = 0
-        if not hasattr(self, "_default_vmax"):
-            self._default_vmax = None
+        self._default_opacity = 0.5
 
     def set_image(self, image):
         """Set associated image, initialising it if needed."""
@@ -39,6 +38,9 @@ class ImageOverlay(skrt.image.Image):
     def plot(
         self, 
         view=None,
+        sl=None,
+        idx=None,
+        pos=None,
         ax=None,
         gs=None,
         figsize=None,
@@ -59,6 +61,19 @@ class ImageOverlay(skrt.image.Image):
             "x-z".  If None, the initial view is chosen to match
             the image orienation.
 
+        sl : int, default=None
+            Slice number to plot. Takes precedence over <idx> and <pos> if not
+            None. If all of <sl>, <idx>, and <pos> are None, the central
+            slice will be plotted.
+
+        idx : int, default=None
+            Index of the slice in the array to plot. Takes precendence over
+            <pos>.
+
+        pos : float, default=None
+            Position in mm of the slice to plot. Will be rounded to the nearest
+            slice. Only used if <sl> and <idx> are both None.
+
         ax : matplotlib.pyplot.Axes, default=None
             Axes on which to plot. If None, new axes will be created.
 
@@ -97,13 +112,14 @@ class ImageOverlay(skrt.image.Image):
         self.set_ax(view, ax, gs, figsize, zoom, colorbar)
         self.load()
 
-        # Plot underlying image
+        # Plot underlying image, always without title.
         if include_image and self.image is not None:
-            self.image.plot(view, ax=self.ax, show=False)
+            self.image.plot(view, sl=sl, idx=idx, pos=pos, ax=self.ax,
+                    show=False, title="")
 
             # Use default transprency if plotting image and opacity is None
             if opacity is None:
-                opacity = 0.5
+                opacity = self._default_opacity
 
         # Add opacity to mpl_kwargs
         if mpl_kwargs is None:
@@ -115,6 +131,9 @@ class ImageOverlay(skrt.image.Image):
         skrt.image.Image.plot(
             self, 
             view=view,
+            sl=sl,
+            idx=idx,
+            pos=pos,
             ax=self.ax,
             zoom=zoom,
             colorbar=colorbar,
@@ -123,35 +142,6 @@ class ImageOverlay(skrt.image.Image):
             **kwargs
         )
 
-
-    def view(self, include_image=True, kwarg_name=None, **kwargs):
-        """View with BetterViewer, optionally overlaying on image.
-
-        **Parameters**:
-
-        include_image : bool, default=False
-            If True, this ImageOverlay will be displayed overlaid on its
-            underlying Image.
-
-        kwarg_name : str, default=None
-            Name of kwarg under which to provide self to the call to
-            self.image.Image.view() if include_image=True. By default,
-            self will be passed to the "dose" parameter.
-
-        `**`kwargs :
-            Keyword args to pass to BetterViewer initialisation.
-        """
-
-        from skrt.better_viewer import BetterViewer
-
-        if include_image and self.image is not None:
-            if kwarg_name is None:
-                kwarg_name = "dose"
-            kwargs[kwarg_name] = self
-            return self.image.view(**kwargs)
-
-        return skrt.image.Image.view(self, **kwargs)
-
     @functools.cached_property
     def max(self):
         return self.get_data().max()
@@ -172,18 +162,29 @@ class Dose(ImageOverlay):
         # Plot settings specific to dose map
         self._default_cmap = "jet"
         self._default_colorbar_label = "Dose (Gy)"
+        self._default_opacity = 0.5
 
         # Delete spurious attributes inherited from Image class
         for attribute in ['doses', 'plans']:
             if hasattr(self, attribute):
                 delattr(self, attribute)
 
+        # Initialise additional attributes
+        self.dose_units = None
+        self.dose_type = None
+        self.dose_summation_type = None
+
     def load(self, *args, **kwargs):
         """Load self and set default maximum plotting intensity from max of
         data array if not yet set."""
 
         skrt.image.Image.load(self, *args, **kwargs)
         self._default_vmax = self.max
+        ds = self.dicom_dataset
+        if ds:
+            self.dose_units = getattr(ds, 'DoseUnits', None)
+            self.dose_type = getattr(ds, 'DoseType', None)
+            self.dose_summation_type = getattr(ds, 'DoseSummationType', None)
 
     def set_image(self, image):
         """Set associated image. Image.add_dose(self) will also be called."""
@@ -206,9 +207,17 @@ class Dose(ImageOverlay):
         if self.plan is not None:
             self.plan.add_dose(self)
 
-    def view(self, **kwargs):
+    def get_dose_units(self):
+        self.load()
+        return self.dose_units
 
-        return ImageOverlay.view(self, kwarg_name="dose", **kwargs)
+    def get_dose_type(self):
+        self.load()
+        return self.dose_type
+
+    def get_dose_summation_type(self):
+        self.load()
+        return self.dose_summation_type
 
     def get_dose_in_roi(self, roi):
         """Return 1D numpy array containing all of the dose values for the 
@@ -356,6 +365,7 @@ class Plan(Archive):
         self.path = None
         self.name = None
         self.description = None
+        self.prescription_description = None
         self.approval_status = None
         self.n_fraction_group = None
         self.n_beam_seq = None
@@ -389,6 +399,8 @@ class Plan(Archive):
         self.name = getattr(self.dicom_dataset, 'RTPlanName', None)
         self.description = getattr(
                 self.dicom_dataset, 'RTPlanDescription', None)
+        self.prescription_description = getattr(
+                self.dicom_dataset, 'PrescriptionDescription', None)
 
         try:
             self.approval_status = self.dicom_dataset.ApprovalStatus
@@ -416,6 +428,16 @@ class Plan(Archive):
                         self.target_dose = 0.0
                     for dose in fraction.ReferencedDoseReferenceSequence:
                         self.target_dose += dose.TargetPrescriptionDose
+        dose_reference_sequence = getattr(
+                self.dicom_dataset, 'DoseReferenceSequence', [])
+
+        if self.target_dose is None:
+            target_dose = 0.0
+            for dose_reference in dose_reference_sequence:
+                target_dose = max(target_dose,
+                        getattr(dose_reference, 'TargetPrescriptionDose', 0))
+            if target_dose:
+                self.target_dose = target_dose
 
         self.loaded = True
         self.load_constraints()
@@ -437,8 +459,10 @@ class Plan(Archive):
         
         ds = self.get_dicom_dataset()
 
-        for item in ds.DoseReferenceSequence:
-            roi = rois.get(item.ReferencedROINumber, None)
+        dose_reference_sequence = getattr(ds, 'DoseReferenceSequence', [])
+
+        for item in dose_reference_sequence:
+            roi = rois.get(getattr(item, 'ReferencedROINumber', None), None)
             if roi is None:
                 continue
             roi.roi_type = item.DoseReferenceType
@@ -511,13 +535,16 @@ class Plan(Archive):
 
 
         # Return pre-existing result if available.
-        dose_objective = getattr(self.objectives, objective)
+        dose_objective = getattr(self.objectives, objective, None)
         if dose_objective:
             return dose_objective
 
         # Check that data needed for defining dose objective are available.
         rois = self.get_targets()
-        rois.extend(self.get_organs_at_risk())
+        if rois:
+            rois.extend(self.get_organs_at_risk())
+        else:
+            rois = self.get_organs_at_risk()
         if not rois or not (self.doses or dose):
             return dose_objective
 
@@ -548,6 +575,16 @@ class Plan(Archive):
         self.load()
         return self.approval_status
 
+    def get_description(self):
+        '''Return plan description.'''
+        self.load()
+        return self.description
+
+    def get_prescription_description(self):
+        '''Return plan prescription description.'''
+        self.load()
+        return self.prescription_description
+
     def get_n_beam_seq(self):
         '''Return number of beam sequences for this plan.'''
         self.load()
@@ -571,7 +608,7 @@ class Plan(Archive):
     def get_target_dose(self):
         '''Return dose to target (tumour) for this plan.'''
         self.load()
-        return self.name
+        return self.target_dose
 
     def set_image(self, image):
         """Set associated image, initialising it if needed."""
